==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ru.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календарь",
    "Todos" : "Задачи",
    "Personal" : "Личное",
    "{actor} created calendar {calendar}" : "{actor} создал(а) календарь «{calendar}»",
    "You created calendar {calendar}" : "Вы создали календарь «{calendar}»",
    "{actor} deleted calendar {calendar}" : "{actor} удалил(а) календарь «{calendar}»",
    "You deleted calendar {calendar}" : "Вы удалили календарь «{calendar}»",
    "{actor} updated calendar {calendar}" : "{actor} обновил(а) календарь «{calendar}»",
    "You updated calendar {calendar}" : "Вы обновили календарь «{calendar}»",
    "You shared calendar {calendar} as public link" : "Вы предоставили общий доступ к календарю «{calendar}» созданием общедоступной ссылки",
    "You removed public link for calendar {calendar}" : "Вы удалили общедоступную ссылку на календарь «{calendar}»",
    "{actor} shared calendar {calendar} with you" : "{actor} предоставил(а) вам общий доступ к календарю «{calendar}»",
    "You shared calendar {calendar} with {user}" : "Вы предоставили пользователю {user} общий доступ к календарю «{calendar}»",
    "{actor} shared calendar {calendar} with {user}" : "{actor} предоставил(а) пользователю {user} общий доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from you" : "{actor} закрыл(а) вам доступ к календарю «{calendar}»",
    "You unshared calendar {calendar} from {user}" : "Вы закрыли пользователю {user} доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} закрыл(а) пользователю {user} доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} закрыл(а) себе доступ к календарю «{calendar}»",
    "You shared calendar {calendar} with group {group}" : "Вы предоставили группе {group} общий доступ к календарю «{calendar}»",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} предоставил(а) группе {group} общий доступ к календарю «{calendar}»",
    "You unshared calendar {calendar} from group {group}" : "Вы закрыли группе {group} общий доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} закрыл(а) группе {group} общий доступ к календарю «{calendar}»",
    "{actor} created event {event} in calendar {calendar}" : "{actor} создал(а) событие «{event}» в календаре «{calendar}»",
    "You created event {event} in calendar {calendar}" : "Вы создали событие «{event}» в календаре «{calendar}»",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} удалил(а) событие «{event}» из календаря «{calendar}»",
    "You deleted event {event} from calendar {calendar}" : "Вы удалили событие «{event}» из календаря «{calendar}»",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} обновил(а) событие «{event}» в календаре «{calendar}»",
    "You updated event {event} in calendar {calendar}" : "Вы обновили событие «{event}» в календаре «{calendar}»",
    "{actor} created todo {todo} in list {calendar}" : "{actor} создал(а) задачу «{todo}» в списке «{calendar}»",
    "You created todo {todo} in list {calendar}" : "Вы создали задачу «{todo}» в списке «{calendar}»",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} удалил(а) задачу «{todo}» из списка «{calendar}»",
    "You deleted todo {todo} from list {calendar}" : "Вы удалили задачу «{todo}» из списка «{calendar}»",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} обновил(а) задачу «{todo}» из списка «{calendar}»",
    "You updated todo {todo} in list {calendar}" : "Вы обновили задачу «{todo}» из списка «{calendar}»",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} завершил(а) задачу «{todo}» из списка «{calendar}»",
    "You solved todo {todo} in list {calendar}" : "Вы завершили задачу «{todo}» из списка «{calendar}»",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} повторно(а) открыл задачу «{todo}» из списка «{calendar}»",
    "You reopened todo {todo} in list {calendar}" : "Вы повторно открыли задачу «{todo}» из списка «{calendar}»",
    "A <strong>calendar</strong> was modified" : "<strong>Календарь</strong> был изменен",
    "A calendar <strong>event</strong> was modified" : "<strong>Событие</strong> календаря была изменено",
    "A calendar <strong>todo</strong> was modified" : "<strong>Задача</strong> календаря была изменена",
    "Contact birthdays" : "Дни рождения контакта",
    "Invitation canceled" : "Приглашение отменено",
    "Hello %s," : "Привет, %s!",
    "Invitation updated" : "Приглашение обновлено",
    "When:" : "Когда:",
    "Where:" : "Где:",
    "Description:" : "Описание:",
    "Link:" : "Ссылка:",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "More options …" : "Дополнительные параметры…",
    "More options at %s" : "Дополнительные параметры на %s",
    "Contacts" : "Контакты",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "точка подключения WebDAV",
    "Technical details" : "Технические подробности",
    "Remote Address: %s" : "Удаленный адрес: %s",
    "Request ID: %s" : "ID запроса: %s",
    "There was an error updating your attendance status." : "Ошибка обновления статуса участия.",
    "Please contact the organizer directly." : "Обратитесь к организатору напрямую.",
    "Are you accepting the invitation?" : "Принять приглашение?",
    "Tentative" : "Под вопросом",
    "Save" : "Сохранить",
    "Your attendance was updated successfully." : "Статус участия обновлён.",
    "Calendar server" : "Сервер календаря",
    "Send invitations to attendees" : "Отправить приглашения",
    "Please make sure to properly set up the email settings above." : "Проверьте правильность заданных выше параметров электронной почты.",
    "Automatically generate a birthday calendar" : "Создавать календарь дней рождения автоматически",
    "Birthday calendars will be generated by a background job." : "Календари дней рождения будут создаваться фоновым процессом.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "И поэтому они станут доступны не моментально, а через некоторое время.",
    "%s via %s" : "%s через %s",
    "The meeting »%s« with %s was canceled." : "Встреча «%s» с %s отменена.",
    "The meeting »%s« with %s was updated." : "Встреча «%s» с %s обновлена.",
    "%s invited you to »%s«" : "%s пригласил(а) Вас на «%s»",
    "CalDAV server" : "CalDAV сервер"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ru.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календарь",
    "Todos" : "Задачи",
    "Personal" : "Личное",
    "{actor} created calendar {calendar}" : "{actor} создал(а) календарь «{calendar}»",
    "You created calendar {calendar}" : "Вы создали календарь «{calendar}»",
    "{actor} deleted calendar {calendar}" : "{actor} удалил(а) календарь «{calendar}»",
    "You deleted calendar {calendar}" : "Вы удалили календарь «{calendar}»",
    "{actor} updated calendar {calendar}" : "{actor} обновил(а) календарь «{calendar}»",
    "You updated calendar {calendar}" : "Вы обновили календарь «{calendar}»",
    "You shared calendar {calendar} as public link" : "Вы предоставили общий доступ к календарю «{calendar}» созданием общедоступной ссылки",
    "You removed public link for calendar {calendar}" : "Вы удалили общедоступную ссылку на календарь «{calendar}»",
    "{actor} shared calendar {calendar} with you" : "{actor} предоставил(а) вам общий доступ к календарю «{calendar}»",
    "You shared calendar {calendar} with {user}" : "Вы предоставили пользователю {user} общий доступ к календарю «{calendar}»",
    "{actor} shared calendar {calendar} with {user}" : "{actor} предоставил(а) пользователю {user} общий доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from you" : "{actor} закрыл(а) вам доступ к календарю «{calendar}»",
    "You unshared calendar {calendar} from {user}" : "Вы закрыли пользователю {user} доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} закрыл(а) пользователю {user} доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} закрыл(а) себе доступ к календарю «{calendar}»",
    "You shared calendar {calendar} with group {group}" : "Вы предоставили группе {group} общий доступ к календарю «{calendar}»",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} предоставил(а) группе {group} общий доступ к календарю «{calendar}»",
    "You unshared calendar {calendar} from group {group}" : "Вы закрыли группе {group} общий доступ к календарю «{calendar}»",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} закрыл(а) группе {group} общий доступ к календарю «{calendar}»",
    "{actor} created event {event} in calendar {calendar}" : "{actor} создал(а) событие «{event}» в календаре «{calendar}»",
    "You created event {event} in calendar {calendar}" : "Вы создали событие «{event}» в календаре «{calendar}»",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} удалил(а) событие «{event}» из календаря «{calendar}»",
    "You deleted event {event} from calendar {calendar}" : "Вы удалили событие «{event}» из календаря «{calendar}»",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} обновил(а) событие «{event}» в календаре «{calendar}»",
    "You updated event {event} in calendar {calendar}" : "Вы обновили событие «{event}» в календаре «{calendar}»",
    "{actor} created todo {todo} in list {calendar}" : "{actor} создал(а) задачу «{todo}» в списке «{calendar}»",
    "You created todo {todo} in list {calendar}" : "Вы создали задачу «{todo}» в списке «{calendar}»",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} удалил(а) задачу «{todo}» из списка «{calendar}»",
    "You deleted todo {todo} from list {calendar}" : "Вы удалили задачу «{todo}» из списка «{calendar}»",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} обновил(а) задачу «{todo}» из списка «{calendar}»",
    "You updated todo {todo} in list {calendar}" : "Вы обновили задачу «{todo}» из списка «{calendar}»",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} завершил(а) задачу «{todo}» из списка «{calendar}»",
    "You solved todo {todo} in list {calendar}" : "Вы завершили задачу «{todo}» из списка «{calendar}»",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} повторно(а) открыл задачу «{todo}» из списка «{calendar}»",
    "You reopened todo {todo} in list {calendar}" : "Вы повторно открыли задачу «{todo}» из списка «{calendar}»",
    "A <strong>calendar</strong> was modified" : "<strong>Календарь</strong> был изменен",
    "A calendar <strong>event</strong> was modified" : "<strong>Событие</strong> календаря была изменено",
    "A calendar <strong>todo</strong> was modified" : "<strong>Задача</strong> календаря была изменена",
    "Contact birthdays" : "Дни рождения контакта",
    "%1$s via %2$s" : "%1$sчерез %2$s",
    "Invitation canceled" : "Приглашение отменено",
    "Hello %s," : "Привет, %s!",
    "The meeting »%1$s« with %2$s was canceled." : "Встреча «%1$s» с %2$s отменена.",
    "Invitation updated" : "Приглашение обновлено",
    "The meeting »%1$s« with %2$s was updated." : "Встреча «%1$s» с %2$s обновлена.",
    "%1$s invited you to »%2$s«" : "%1$sприглашает вас в  »%2$s«",
    "When:" : "Когда:",
    "Where:" : "Где:",
    "Description:" : "Описание:",
    "Link:" : "Ссылка:",
    "Accept" : "Принять",
    "Decline" : "Отклонить",
    "More options …" : "Дополнительные параметры…",
    "More options at %s" : "Дополнительные параметры на %s",
    "Contacts" : "Контакты",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "точка подключения WebDAV",
    "Technical details" : "Технические подробности",
    "Remote Address: %s" : "Удаленный адрес: %s",
    "Request ID: %s" : "ID запроса: %s",
    "There was an error updating your attendance status." : "Ошибка обновления статуса участия.",
    "Please contact the organizer directly." : "Обратитесь к организатору напрямую.",
    "Are you accepting the invitation?" : "Принять приглашение?",
    "Tentative" : "Под вопросом",
    "Save" : "Сохранить",
    "Your attendance was updated successfully." : "Статус участия обновлён.",
    "Calendar server" : "Сервер календаря",
    "Send invitations to attendees" : "Отправить приглашения",
    "Please make sure to properly set up the email settings above." : "Проверьте правильность заданных выше параметров электронной почты.",
    "Automatically generate a birthday calendar" : "Создавать календарь дней рождения автоматически",
    "Birthday calendars will be generated by a background job." : "Календари дней рождения будут создаваться фоновым процессом.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "И поэтому они станут доступны не моментально, а через некоторое время.",
    "%s via %s" : "%s через %s",
    "The meeting »%s« with %s was canceled." : "Встреча «%s» с %s отменена.",
    "The meeting »%s« with %s was updated." : "Встреча «%s» с %s обновлена.",
    "%s invited you to »%s«" : "%s пригласил(а) Вас на «%s»",
    "CalDAV server" : "CalDAV сервер"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
